@@ -11,10 +11,15 @@ In the Docs you will find further information about.
 from .server_unreachable_error import ServerUnreachableError
 from .server_method_call_error import ServerMethodCallError
 from .client_method_call_error import ClientMethodCallError
-
+from .invalid_log_level_error import InvalidLogLevelError
+from .invalid_handler_method_error import InvalidHandlerMethodError
+from .handler_not_found_error import HandlerNotFoundError
 
 __all__ = [
     "ServerUnreachableError",
     "ServerMethodCallError",
-    "ClientMethodCallError"
+    "ClientMethodCallError",
+    "InvalidLogLevelError",
+    "InvalidHandlerMethodError",
+    "HandlerNotFoundError"
     ]
